window.Gleam.initSearch([{"doc":"argus","title":"argus","content":"# Argus\n\nArgon2 password hashing library for Gleam, based on the reference C implementation.\n\n[![Package Version](https://img.shields.io/hexpm/v/antigone)](https://hex.pm/packages/antigone)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/antigone/)\n\nThis library uses another Pevensie project, [jargon](https://github.com/Pevensie/jargon), to provide the underlying NIF.\n\nIt currently only supports Gleam&#39;s Erlang backend.\n\n## Example\n\n```bash\ngleam add argus\n```\n\n```gleam\nimport argus\n\npub fn main() {\n  // Hash a password using the recommended settings for Argon2id.\n  let assert Ok(hashes) =\n    argus.hasher()\n    |&gt; argus.hash(&quot;password&quot;, gen_salt())\n\n  // Hash a password with custom settings and a custom salt.\n  let assert Ok(hashes) =\n    argus.hasher()\n    |&gt; argus.algorithm(argus.Argon2id)\n    |&gt; argus.time_cost(3)\n    |&gt; argus.memory_cost(12228) // 12 mebibytes\n    |&gt; argus.parallelism(1)\n    |&gt; argus.hash_length(32)\n    |&gt; argus.hash(&quot;password&quot;, &quot;custom_salt&quot;)\n\n  // Verify a password.\n  let assert Ok(True) = argus.verify(hashes.encoded_hash, &quot;password&quot;)\n}\n```\n\nMore information can be found in the [documentation](https://hexdocs.pm/argus/).\n\n## Why &#39;Argus&#39;?\n\n[Argus](https://en.wikipedia.org/wiki/Argus_(Argonaut)) was the builder of the\n[Argo](https://en.wikipedia.org/wiki/Argo) ship and was one of the\n[Argonauts](https://en.wikipedia.org/wiki/Argonauts).\n","url":"index.html"},{"doc":"argus","title":"Argon2Algorithm","content":"pub type Argon2Algorithm {\n  Argon2d\n  Argon2i\n  Argon2id\n}\n\nArgon2d\n\n\nArgon2i\n\n\nArgon2id\n\n\nSynonyms:\nargus.Argon2Algorithm\nargus Argon2Algorithm","url":"argus.html#Argon2Algorithm"},{"doc":"argus","title":"HashError","content":"pub type HashError {\n  OutputPointerIsNull\n  OutputTooShort\n  OutputTooLong\n  PasswordTooShort\n  PasswordTooLong\n  SaltTooShort\n  SaltTooLong\n  AssociatedDataTooShort\n  AssociatedDataTooLong\n  SecretTooShort\n  SecretTooLong\n  TimeCostTooSmall\n  TimeCostTooLarge\n  MemoryCostTooSmall\n  MemoryCostTooLarge\n  TooFewLanes\n  TooManyLanes\n  PasswordPointerMismatch\n  SaltPointerMismatch\n  SecretPointerMismatch\n  AssociatedDataPointerMismatch\n  MemoryAllocationError\n  FreeMemoryCallbackNull\n  AllocateMemoryCallbackNull\n  IncorrectParameter\n  IncorrectType\n  InvalidAlgorithm\n  OutputPointerMismatch\n  TooFewThreads\n  TooManyThreads\n  NotEnoughMemory\n  EncodingFailed\n  DecodingFailed\n  ThreadFailure\n  DecodingLengthFailure\n  VerificationFailure\n  UnknownErrorCode\n}\n All possible Argon2 hashing errors.\n Most are unlikely to occur, but it&#39;s good to be aware of them.\nOutputPointerIsNull\n\n\nOutputTooShort\n\n\nOutputTooLong\n\n\nPasswordTooShort\n\n\nPasswordTooLong\n\n\nSaltTooShort\n\n\nSaltTooLong\n\n\nAssociatedDataTooShort\n\n\nAssociatedDataTooLong\n\n\nSecretTooShort\n\n\nSecretTooLong\n\n\nTimeCostTooSmall\n\n\nTimeCostTooLarge\n\n\nMemoryCostTooSmall\n\n\nMemoryCostTooLarge\n\n\nTooFewLanes\n\n\nTooManyLanes\n\n\nPasswordPointerMismatch\n\n\nSaltPointerMismatch\n\n\nSecretPointerMismatch\n\n\nAssociatedDataPointerMismatch\n\n\nMemoryAllocationError\n\n\nFreeMemoryCallbackNull\n\n\nAllocateMemoryCallbackNull\n\n\nIncorrectParameter\n\n\nIncorrectType\n\n\nInvalidAlgorithm\n\n\nOutputPointerMismatch\n\n\nTooFewThreads\n\n\nTooManyThreads\n\n\nNotEnoughMemory\n\n\nEncodingFailed\n\n\nDecodingFailed\n\n\nThreadFailure\n\n\nDecodingLengthFailure\n\n\nVerificationFailure\n\n\nUnknownErrorCode\n\n\nSynonyms:\nargus.HashError\nargus HashError","url":"argus.html#HashError"},{"doc":"argus","title":"Hasher","content":"pub opaque type Hasher\n\n\nSynonyms:\nargus.Hasher\nargus Hasher","url":"argus.html#Hasher"},{"doc":"argus","title":"Hashes","content":"pub type Hashes {\n  Hashes(raw_hash: BitArray, encoded_hash: String)\n}\n\nHashes(raw_hash: BitArray, encoded_hash: String)\n\n\nSynonyms:\nargus.Hashes\nargus Hashes","url":"argus.html#Hashes"},{"doc":"argus","title":"algorithm","content":"pub fn algorithm(\n  hasher: Hasher,\n  algorithm: Argon2Algorithm,\n) -&gt; Hasher\n Set the algorithm to use for the hasher.\nSynonyms:\nargus.algorithm\nargus algorithm","url":"argus.html#algorithm"},{"doc":"argus","title":"gen_salt","content":"pub fn gen_salt() -&gt; String\n Generate a random salt of at least 64 bytes.\nSynonyms:\nargus.gen_salt\nargus gen_salt","url":"argus.html#gen_salt"},{"doc":"argus","title":"hash","content":"pub fn hash(\n  hasher: Hasher,\n  password: String,\n  salt: String,\n) -&gt; Result(Hashes, HashError)\n Hash a password using the provided hasher.\n \n ## Examples\n \n \n import argus\n \n let assert Ok(hashes) =\n   argus.hasher()\n   |&gt; argus.algorithm(argus.Argon2id)\n   |&gt; argus.time_cost(3)\n   |&gt; argus.memory_cost(12228)\n   |&gt; argus.parallelism(1)\n   |&gt; argus.hash_length(32)\n   |&gt; argus.hash(&quot;password&quot;, gen_salt())\n \n let assert Ok(True) = argus.verify(hashes.encoded_hash, &quot;password&quot;)\n \nSynonyms:\nargus.hash\nargus hash","url":"argus.html#hash"},{"doc":"argus","title":"hash_length","content":"pub fn hash_length(hasher: Hasher, hash_length: Int) -&gt; Hasher\n Set the hash length to use for the hasher.\nSynonyms:\nargus.hash_length\nargus hash_length","url":"argus.html#hash_length"},{"doc":"argus","title":"hasher","content":"pub fn hasher() -&gt; Hasher\n Create a new hasher with default settings based on the\n [OWASP recommendations](https://cheatsheetseries.owasp.org/cheatsheets/Password_Storage_Cheat_Sheet.html#argon2id).\n\n Note: if you change the algorithm to Argon2i, you will need to change the\n `memory_cost` to 12_228 (12 mebibytes) or less for performance reasons.\n\n The `hasher_argon2i` function is provided with the recommended settings for\n Argon2i.\nSynonyms:\nargus.hasher\nargus hasher","url":"argus.html#hasher"},{"doc":"argus","title":"hasher_argon2i","content":"pub fn hasher_argon2i() -&gt; Hasher\n Create a new hasher with default settings based on the\n [OWASP recommendations](https://cheatsheetseries.owasp.org/cheatsheets/Password_Storage_Cheat_Sheet.html#argon2id) for\n Argon2i.\nSynonyms:\nargus.hasher_argon2i\nargus hasher_argon2i","url":"argus.html#hasher_argon2i"},{"doc":"argus","title":"memory_cost","content":"pub fn memory_cost(hasher: Hasher, memory_cost: Int) -&gt; Hasher\n Set the memory cost to use for the hasher.\nSynonyms:\nargus.memory_cost\nargus memory_cost","url":"argus.html#memory_cost"},{"doc":"argus","title":"parallelism","content":"pub fn parallelism(hasher: Hasher, parallelism: Int) -&gt; Hasher\n Set the parallelism to use for the hasher.\nSynonyms:\nargus.parallelism\nargus parallelism","url":"argus.html#parallelism"},{"doc":"argus","title":"time_cost","content":"pub fn time_cost(hasher: Hasher, time_cost: Int) -&gt; Hasher\n Set the time cost to use for the hasher.\nSynonyms:\nargus.time_cost\nargus time_cost","url":"argus.html#time_cost"},{"doc":"argus","title":"verify","content":"pub fn verify(\n  encoded_hash: String,\n  password: String,\n) -&gt; Result(Bool, HashError)\n Verify a password using the provided encoded hash.\nSynonyms:\nargus.verify\nargus verify","url":"argus.html#verify"},{"doc":"argus","title":"argus","content":"","url":"argus.html"}]);